summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/test_arr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpat/freecell-solver/test_arr.h')
-rw-r--r--kpat/freecell-solver/test_arr.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kpat/freecell-solver/test_arr.h b/kpat/freecell-solver/test_arr.h
index 821ccd98..911ff511 100644
--- a/kpat/freecell-solver/test_arr.h
+++ b/kpat/freecell-solver/test_arr.h
@@ -26,19 +26,19 @@ typedef int (*freecell_solver_solve_for_state_test_t)(
extern freecell_solver_solve_for_state_test_t freecell_solver_sfs_tests[FCS_TESTS_NUM];
/*
* This macro determines if child can be placed above tqparent.
*
* The variable sequences_are_built_by has to be initialized to
* the sequences_are_built_by member of the instance.
*
* */
-#define fcs_is_parent_card(child, tqparent) \
- ((fcs_card_card_num(child)+1 == fcs_card_card_num(tqparent)) && \
+#define fcs_is_parent_card(child, parent) \
+ ((fcs_card_card_num(child)+1 == fcs_card_card_num(parent)) && \
((sequences_are_built_by == FCS_SEQ_BUILT_BY_RANK) ? \
1 : \
((sequences_are_built_by == FCS_SEQ_BUILT_BY_SUIT) ? \
- (fcs_card_suit(child) == fcs_card_suit(tqparent)) : \
- ((fcs_card_suit(child) & 0x1) != (fcs_card_suit(tqparent)&0x1)) \
+ (fcs_card_suit(child) == fcs_card_suit(parent)) : \
+ ((fcs_card_suit(child) & 0x1) != (fcs_card_suit(parent)&0x1)) \
)) \
)
@@ -58,7 +58,7 @@ extern freecell_solver_solve_for_state_test_t freecell_solver_sfs_tests[FCS_TEST
/* Count the number of states until the original state. */ \
while(ptr_state != NULL) \
{ \
- ptr_state = ptr_state->tqparent; \
+ ptr_state = ptr_state->parent; \
this_real_depth++; \
} \
this_real_depth--; \
@@ -68,14 +68,14 @@ extern freecell_solver_solve_for_state_test_t freecell_solver_sfs_tests[FCS_TEST
{ \
ptr_state->depth = this_real_depth; \
this_real_depth--; \
- ptr_state = ptr_state->tqparent; \
+ ptr_state = ptr_state->parent; \
} \
} \
} \
/*
* This macro marks a state as a dead end, and afterwards propogates
* this information to its tqparent and ancestor states.
* */
#define mark_as_dead_end(ptr_state_input) \
{ \
@@ -84,7 +84,7 @@ extern freecell_solver_solve_for_state_test_t freecell_solver_sfs_tests[FCS_TEST
fcs_state_with_locations_t * ptr_state = (ptr_state_input); \
/* Mark as a dead end */ \
ptr_state->visited |= FCS_VISITED_DEAD_END; \
- ptr_state = ptr_state->tqparent; \
+ ptr_state = ptr_state->parent; \
if (ptr_state != NULL) \
{ \
/* Decrease the refcount of the state */ \
@@ -93,8 +93,8 @@ extern freecell_solver_solve_for_state_test_t freecell_solver_sfs_tests[FCS_TEST
{ \
/* Mark as dead end */ \
ptr_state->visited |= FCS_VISITED_DEAD_END; \
- /* Go to its tqparent state */ \
- ptr_state = ptr_state->tqparent; \
+ /* Go to its parent state */ \
+ ptr_state = ptr_state->parent; \
if (ptr_state == NULL) \
{ \
break; \
@@ -26,19 +26,19 @@ typedef int (*freecell_solver_solve_for_state_test_t)(
extern freecell_solver_solve_for_state_test_t freecell_solver_sfs_tests[FCS_TESTS_NUM];
/*
- * This macro determines if child can be placed above tqparent.
+ * This macro determines if child can be placed above parent.
*
* The variable sequences_are_built_by has to be initialized to
@@ -68,14 +68,14 @@ extern freecell_solver_solve_for_state_test_t freecell_solver_sfs_tests[FCS_TEST
/*
* This macro marks a state as a dead end, and afterwards propogates
- * this information to its tqparent and ancestor states.
+ * this information to its parent and ancestor states.
* */
#define mark_as_dead_end(ptr_state_input) \